@@ -3,7 +3,7 @@ from .check import (check_for_nodes, check_for_duplicates, check_for_duplicate_l
 from .collection import nodes_dict, links_dict, subcatchments_per_node_dict, nodes_subcatchments_dict
 from .compare import CompareSections, compare_inp_files, compare_sections
 from .convert_model import to_kinematic_wave
-from .convert_object import junction_to_storage, junction_to_outfall, conduit_to_orifice
+from .convert_object import junction_to_storage, junction_to_outfall, conduit_to_orifice, storage_to_outfall, junction_to_divider
 from .curve import curve_figure
 from .edit import (combine_conduits, combine_conduits_keep_slope, combine_vertices, delete_link, delete_node,
                    delete_subcatchment, dissolve_conduit, flip_link_direction, move_flows, rename_link, rename_node,
@@ -27,17 +27,18 @@ except ImportError as e:
 
 from .graph import (inp_to_graph, get_path, get_path_subgraph, next_links, next_links_labels, next_nodes,
                     previous_links, previous_links_labels, previous_nodes, links_connected, number_in_out,
-                    downstream_nodes, upstream_nodes, get_network_forks, split_network, conduit_iter_over_inp)
+                    downstream_nodes, upstream_nodes, get_network_forks, split_network, conduit_iter_over_inp,
+                    subcatchments_connected)
 from .macros import (find_node, find_link, calc_slope, conduit_slopes, conduits_are_equal, update_no_duplicates,
                      increase_max_node_depth, set_times, combined_subcatchment_frame, delete_sections,
                      set_absolute_file_paths)
-from .plotting_longitudinal import plot_longitudinal
+from .plotting_longitudinal import plot_longitudinal, animated_plot_longitudinal
 from .plotting_map import (plot_map, init_empty_map_plot, add_node_map, add_link_map, add_subcatchment_map,
                            add_node_labels, set_inp_dimensions, add_backdrop)
 from .reduce_unneeded import (reduce_curves, reduce_controls, simplify_curves, reduce_raingages,
                               remove_empty_sections, reduce_timeseries, reduce_pattern)
 from .split_inp_file import split_inp_to_files, read_split_inp_file
-from .summerize import print_summary
+from .summarize import print_summary
 from ._helpers import get_used_curves
 from .tags import get_node_tags, get_link_tags, get_subcatchment_tags, filter_tags, delete_tag_group
 
